% Markus Kowalsky
% The Johns Hopkins University

%$%%%%%%%%%%%%%%%%%%%%%%%%%    PARAMETERS    %%%%%%%%%%%%%%%%%%%%%%%%%$%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$ CURVE LENGTH TRANSFORMATION FOR:                                   $%
%$ width: window width in ms                                          $%
%$ data: ECG data                                                     $%
%$ sampling_rate: 2048 Hz etc.                                        $%
%$ type: for changing the constant C as denoted in Zong's 2006 paper  $%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%$%

function curve_length_data = lengthTransform(width,data,sampling_rate,type)
width = numSamp(width,sampling_rate,'ms');

% make sure data is right dimension
data_dim = size(data);
if data_dim(1,1) ~= 1
  data = data';
end

% checks
if width < 1 || width > length(data)
  disp(['You entered an invalid window length. Please try again with a window length between 1 and ', num2str(length(data)),'.'])
end

% changing constant C
C = (1/sampling_rate)^2; % default value (very low C);
if strcmp(type,'QRS')
  C = 50;
elseif strcmp(type,'T')
  C = (1/sampling_rate)^2;
end;

% compute curve length data
curve_length_data = zeros(1,length(data));
for i = 1:length(data)
  start = i-width;
  if start < 2
    start = 2;
  end
  finish = max([i start]);
  for j = start:finish
    curve_length_data(i) = curve_length_data(i) + sqrt(C + (data(j) - data(j-1))^2);
  end
end
end