% Markus Kowalsky
% The Johns Hopkins University

%$%%%%%%%%%%%%%%%%%    PARAMETERS   %%%%%%%%%%%%%%%%%%$%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$ figure_handle (handle to figure to be printed)     $%
%$ figure_types                                       $%
%$   1) 'ECG'                                         $%
%$   2) 'INTRACARDIAC'                                $%
%$   3) 'BODY SURFACE'                                $%
%$ lead_number (to be appended to file)               $%
%$ folder_name (where to print to)                    $%
%$ *all should be case-insenstive                     $%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%$%

function status = printFigure(figure_handle, figure_type, lead_number, folder_name)
try
% make parameters case-insensitive
map_type = upper(figure_type);
folder_name = upper(folder_name);
% check if folder exists
if exist(folder_name,'dir') == 0
  mkdir(pwd,folder_name);
end
% prints the figure to specified directory
if strcmp(figure_type,'INTRACARDIAC')
  fig_name = get(figure_handle,'Name');
  ymdhms = clock;
  filename = [pwd,'/',folder_name,'/',fig_name, ' on ', num2str(ymdhms(1,2)),'-', ...
    num2str(ymdhms(1,3)),'-', num2str(ymdhms(1,1)), ' at ' ...
    ,num2str(ymdhms(1,4)),'-', num2str(ymdhms(1,5))];
elseif strcmp(figure_type,'ECG')
  fig_name = get(figure_handle,'Name');
  ymdhms = clock;
  filename = [pwd,'/',folder_name,'/Lead-', num2str(lead_number), '-', ...
    fig_name, ' on ', num2str(ymdhms(1,2)),'-', num2str(ymdhms(1,3)), ...
    '-', num2str(ymdhms(1,1)), ' at ',num2str(ymdhms(1,4)), ...
    '-', num2str(ymdhms(1,5))];
elseif strcmp(figure_type,'BODY SURFACE')
  fig_name = get(figure_handle,'Name');
  ymdhms = clock;
  filename = [pwd,'/',folder_name,'/',fig_name, ' on ', num2str(ymdhms(1,2)),'-', ...
    num2str(ymdhms(1,3)),'-', num2str(ymdhms(1,1)), ' at ' ...
    ,num2str(ymdhms(1,4)),'-', num2str(ymdhms(1,5))];
end
print(figure_handle,'-djpeg100', filename)
status = 'Success';
catch ME
  disp(ME.message);
end
end

