function func_status = testFiducialPoints(run_type,debug_type,delay,print_option)
func_status = 0;
%% Setup
% make parameters case-insensitive
run_type = upper(run_type);
debug_type = upper(debug_type);

% Directory to print to
ymdhms = clock;
folder_name = ['Figures on ',num2str(ymdhms(1,2)),'-',...
  num2str(ymdhms(1,3)),'-',num2str(ymdhms(1,1)),' at ',...
  num2str(ymdhms(1,4)),'-',num2str(ymdhms(1,5))];

% Load necessary files
load 1c06h004_03.avg2.mat
load 1c06h004_03_ZBH_tri_I.mat

%% Body Surface
if strcmp(run_type,'BOTH') || strcmp(run_type,'BODY SURFACE')
  
  for i = 1:120
    disp(['Lead ',num2str(i)]);
    data = PHIB_AVG.PHI120_avg(:,i);
    [Qbs, Rbs, Sbs, Tbs] = findFiducialPointsSingleBeat(data,2048,debug_type,1.2,[300 700]);
    [SAI_QRSTs(i), I_QRSTs(i)] = findIntegrals(data,Qbs, Tbs);
    Peak2Peak(i) = findPeak2Peak(data,Qbs,Sbs);
    QT_int(i) = 1000*(Tbs - Qbs)./2048;
    if ~strcmp(debug_type,'NORMAL')
      if strcmp(debug_type,'DEBUG-A')
        status = printFigure(gcf, 'ECG', i, [folder_name, '/Body Surface/']);
      end
      if strcmp(debug_type,'DEBUG-B')
        for j = 1:6
          h = figure(j);
          status = printFigure(h, 'ECG', i, [folder_name, '/Body Surface/']);
        end
      end
      tilefigs;
      pause(delay)
      close all;
    end
  end
  if strcmp(print_option,'PRINT')
    % Create body surface map
    map1 = create_map('Body Surface', 'SAI QRST', SAI_QRSTs, 'INVERTED', 'FRONT');
    map2 = create_map('Body Surface', 'SAI QRST', SAI_QRSTs, 'INVERTED', 'BACK');
    map3 = create_map('Body Surface', 'QRST INTEGRAL', I_QRSTs, 'INVERTED', 'FRONT');
    map4 = create_map('Body Surface', 'QRST INTEGRAL', I_QRSTs, 'INVERTED', 'BACK');
    map5 = create_map('Body Surface', 'P2P Voltage', Peak2Peak, 'INVERTED', 'FRONT');
    map6 = create_map('Body Surface', 'P2P Voltage', Peak2Peak, 'INVERTED', 'BACK');
    map7 = create_map('Body Surface', 'Total Repolarization Time', QT_int, 'INVERTED', 'FRONT');
    map8 = create_map('Body Surface', 'Total Repolarization Time', QT_int, 'INVERTED', 'BACK');
    
    
    % Print body surface map
    status = printFigure(map1, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map2, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map3, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map4, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map5, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map6, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map7, 'BODY SURFACE', 1, folder_name);
    status = printFigure(map8, 'BODY SURFACE', 1, folder_name);
  end
end

%% Intracardiac
if strcmp(run_type,'BOTH') || strcmp(run_type,'INTRACARDIAC')
  for i = 1:291
    disp(['Lead ',num2str(i)]);
    data = map3d_heartdata.potvals(i,:);
    [Qbs, Rbs, Sbs, Tbs] = findFiducialPointsSingleBeat(data,2048,debug_type,1.2,[300 700]);
    [SAI_QRSTs(i), I_QRSTs(i)] = findIntegrals(data,Qbs, Tbs);
    Peak2Peak(i) = findPeak2Peak(data,Qbs,Sbs);
    QT_int(i) = 1000*(Tbs - Qbs)./2048;
    if ~strcmp(debug_type,'NORMAL')
      if strcmp(debug_type,'DEBUG-A')
        status = printFigure(gcf, 'ECG', i, [folder_name, '/Intracardiac/']);
      end
      if strcmp(debug_type,'DEBUG-B')
        for j = 1:6
          h = figure(j);
          status = printFigure(h, 'ECG', i, [folder_name, '/Intracardiac/']);
        end
      end
      tilefigs;
      pause(delay)
      close all;
    end
  end
  
  % Average Values
  disp('Average Values');
  disp(['Average SAI QRST: ', num2str(mean(SAI_QRSTs))]);
  disp(['Average Native QRST Integral: ', num2str(mean(I_QRSTs))]);
  disp(['Average Peak to Peak Voltage: ', num2str(mean(Peak2Peak))]);
  disp(['Average QT Interval: ', num2str(mean(QT_int))]);
  
  if strcmp(print_option,'PRINT')
    % Create intracardiac maps
    map1 = create_map('Intracardiac', 'SAI QRST', SAI_QRSTs, 'INVERTED', 'ANTERIOR POSTERIOR');
    map2 = create_map('Intracardiac', 'SAI QRST', SAI_QRSTs, 'INVERTED', 'LEFT POSTERIOR OBLIQUE');
    map3 = create_map('Intracardiac', 'QRST INTEGRAL', I_QRSTs, 'INVERTED', 'ANTERIOR POSTERIOR');
    map4 = create_map('Intracardiac', 'QRST INTEGRAL', I_QRSTs, 'INVERTED', 'LEFT POSTERIOR OBLIQUE');
    map5 = create_map('Intracardiac', 'P2P Voltage', Peak2Peak, 'INVERTED', 'ANTERIOR POSTERIOR');
    map6 = create_map('Intracardiac', 'P2P Voltage', Peak2Peak, 'INVERTED', 'LEFT POSTERIOR OBLIQUE');
    map7 = create_map('Intracardiac', 'Total Repolarization Time', QT_int, 'INVERTED', 'ANTERIOR POSTERIOR');
    map8 = create_map('Intracardiac', 'Total Repolarization Time', QT_int, 'INVERTED', 'LEFT POSTERIOR OBLIQUE');
    
    
    % Print intracardiac maps to directory above
    status = printFigure(map1, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map2, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map3, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map4, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map5, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map6, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map7, 'INTRACARDIAC', 1, folder_name);
    status = printFigure(map8, 'INTRACARDIAC', 1, folder_name);
  end
end
tilefigs
func_status = 1;
end