% Markus Kowalsky
% The Johns Hopkins University

%$%%%%%%%%%%%%%%%%%    PARAMETERS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%$%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$ sets all data between each of the Qs and Ss equal to the average of   $%
%$ the point immediately proceeding each Q fiducial point and the point  $%    
%$ immediately following each S fiducial point                           $%
%$ data: the ECG wave to be zeroed                                       $%
%$ Qs: each of the Q fiducial points                                     $%
%$ Ss: each of the S fiducial points                                     $%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$%
%$%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%$%

function [zeroed_data] = zeroQRScomplex(data,Qbs,Sbs)
% sets all data between each of the Qs and Ss equal to the average of the 
% point immediately proceeding each Q fiducial point and the point
% immediately following each S fiducial point
% PARAMETERS:
% data: the ECG wave to be zeroed
% Qs: each of the Q fiducial points
% Ss: each of the S fiducial points

if length(Qbs) ~= length(Sbs)
  disp('The number of Q and S fiducial points do not match. Continuing anyway')
end

for i = 1:length(Qbs)
  prev_point(i) = data(Qbs(i)-1);
end
for i = 1:length(Sbs)
  future_point(i) = data(Sbs(i)+1);
end
zeroed_data = data; 
j = 1;
for i = 1:length(data)
  if i > Qbs(j) && i < Sbs(j)
    slope(j) = (future_point(j)-prev_point(j))/(Sbs(j) - Qbs(j));
    % zeroed_data(i) = (prev_point(j) + future_point(j))/2;
    zeroed_data(i) = prev_point(j) + slope(j)*(i-Qbs(j));
  end
  if i > Sbs(j)
    j = j + 1;
  end
  if j > length(Qbs)
    break;
  end
end
end

